@@ -4,7 +4,7 @@
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.1                                                         !
+   !    Version 0.1.2                                                         !
    !                                                                          !
    !    Copyright (C) 2014, The localCIDER development team (current and      !
    !                        former contributors): Alex Holehouse, James       !
@@ -125,8 +125,12 @@ class Sequence:
         # initializing to prevent extra computational time
         self.dmax = dmax
 
+        # set phosphosites as empty
         self.phosphosites=[]
 
+        # set color pallete
+        self.set_HTMLColorResiduePalette(aminoacids.DEFAULT_COLOR_PALETTE)
+
 
     #...................................................................................#
     def __unicode__(self):
@@ -292,7 +296,18 @@ class Sequence:
             warning_message("The sequence has no charged residues - kappa is not a valid/relevant parameter")
             return -1
         else:
-            return self.delta()/self.deltaMax()
+            kappaVal = self.delta()/self.deltaMax()
+
+            # so the heuristics for kappa are good BUT may under estimate
+            # deltaMax is some cases. If this is a small deviation then we 
+            # just set it to 0 because the sequence with the highest delta is probably
+            # an sequence-Isomer of the sequence we have. If this deviation is larger,
+            # however, it may be indicative of a bug in the code which we should address
+            if kappaVal > 1.0 and kappaVal < 1.1:
+                return 1.0
+            else:
+                return kappaVal
+            
 
 
     #...................................................................................#
@@ -614,29 +629,109 @@ class Sequence:
         elif(self.FCR() == 0):
             self.dmax = 0
 
-        # First computational trick (Maximum Charge Separation)
+        #################################################################
+        # FIRST computational trick - if only positive or negative 
+        elif self.countPos() == 0 or self.countNeg() == 0:
+            nneuts = self.countNeut()
+            
+            # construct a neutral  block
+            neutralBlock='0'*nneuts
+
+            # construct a charged block
+            if self.countPos() == 0:
+                # make a negative charge block
+                chargedBlock='-'*self.countNeg()
+                chargeV="-"
+                ncharge=self.countNeg()
+                
+            else:
+                # make a positive charge block
+                chargedBlock='+'*self.countPos()
+                chargeV="+"
+                ncharge=self.countPos()
+
+            # if the charge block is shorter than the neutral block
+            if len(neutralBlock) > len(chargedBlock):
+                
+                for position in xrange(0,(self.len-ncharge)+1):
+
+                    setupSequence = position*"0"+chargedBlock+"0"*(nneuts-position)
+
+                    if not len(setupSequence) == self.len:
+                        raise SequenceException("Error in DeltaMax calculation")            
+
+                    nseq = Sequence(setupSequence)
+
+                    # update self.dmax if relevant
+                    self.dmax = max([nseq.delta(), self.dmax])
+            # if the neutral block is shorter
+            else:
+                
+                for position in xrange(0,(self.len-nneuts)+1):
+
+                    setupSequence = position*chargeV+neutralBlock+chargeV*(ncharge-position)
+
+                    if not len(setupSequence) == self.len:
+                        raise SequenceException("Error in DeltaMax calculation")            
+
+                    
+                    nseq = Sequence(setupSequence)
+
+                    # update self.dmax if relevant
+                    self.dmax = max([nseq.delta(), self.dmax])
+
+
+
+        #################################################################
+        # Second computational trick (Maximum Charge Separation)
         # If we have no neutral residues this is easy
         elif(self.countNeut() == 0):
-            setupSequence = ''
-            for i in xrange(0,self.countPos()):
-                setupSequence += '+'
-            for i in xrange(0,self.countNeg()):
-                setupSequence += '-'
-            assert(self.len == len(setupSequence))
-            self.dmax = Sequence(setupSequence).delta()
 
-        #second computational trick (Maximization of # of Charged Blobs)
+            nNeg = self.countNeg()
+            nPos = self.countPos()
+
+            
+            posBlock = "+"*nPos
+            negBlock = "+"*nNeg
+            
+            if len(posBlock) > len(negBlock):
+                for position in xrange(0,(self.len-nNeg)+1):                    
+                    setupSequence = position*"+"+negBlock+"+"*(nPos-position)
+                    
+                    if not len(setupSequence) == self.len:
+                        raise SequenceException("Error in DeltaMax calculation")            
+
+                    
+                    nseq = Sequence(setupSequence)
+
+                    # update self.dmax if relevant
+                    self.dmax = max([nseq.delta(), self.dmax])
+            else:
+                for position in xrange(0,(self.len-nPos)+1):                    
+                    setupSequence = position*"-"+posBlock+"-"*(nNeg-position)
+
+                    
+                    if not len(setupSequence) == self.len:
+                        raise SequenceException("Error in DeltaMax calculation")            
+
+                    
+                    nseq = Sequence(setupSequence)
+
+                    # update self.dmax if relevant
+                    self.dmax = max([nseq.delta(), self.dmax])
+                
+
+
+        #################################################################
+        # Third computational trick (Maximization of # of Charged Blobs)
         # relevant if we have 18 or more neutral residues
         elif(self.countNeut() >= 18):            
             nneuts = self.countNeut()
-            posBlock = ''
-            negBlock = ''
 
             # construct positive and negative blocks
-            for i in xrange(0,self.countPos()):
-                posBlock += '+'
-            for i in xrange(0,self.countNeg()):
-                negBlock += '-'
+            
+            posBlock = '+'*self.countPos()
+            negBlock = '-'*self.countNeg()
 
             # There are three regions where you can have neutral residues
             # to maximize delta: start/middle/end
@@ -649,13 +744,11 @@ class Sequence:
                     setupSequence = ''
                     midBlock = ''
                     endBlock = ''
-                    for i in xrange(startNeuts):
-                        setupSequence += '0'
-                    for i in xrange(0,endNeuts):
-                        endBlock += '0'
-                    for i in xrange(0,nneuts-startNeuts-endNeuts):
-                        midBlock += '0'
-
+                    
+                    setupSequence='0'*startNeuts
+                    endBlock='0'*endNeuts
+                    midBlock='0'*(nneuts-startNeuts-endNeuts)
+                    
                     # now we construct *an* optimal sequence based on the start/mid/end
                     # permutation of neutral residues
                     setupSequence += posBlock
@@ -667,42 +760,38 @@ class Sequence:
                     # update self.dmax if relevant
                     self.dmax = max([nseq.delta(), self.dmax])
 
-        #third computational trick (Search through set of sequences that fit DMAX pattern)
+        #################################################################
+        # Fourth computational trick (Search through set of sequences that fit DMAX pattern)
         else:
             posBlock = ''
             negBlock = ''
             nneuts = self.countNeut()
 
             # construct positive and negative blocks
-            for i in xrange(0,self.countPos()):
-                posBlock += '+'
-
-            for i in xrange(0,self.countNeg()):
-                negBlock += '-'
+            posBlock = '+'*self.countPos()
+            negBlock = '-'*self.countNeg()
 
             # iterate through different permutations where
             #  the size of the middle number of neutral residues varies
             for midNeuts in xrange(0,nneuts+1):
-                midBlock = ''
+                midBlock = '0'*midNeuts
 
-                for i in xrange(0,midNeuts):
-                    midBlock += '0'
 
                 for startNeuts in xrange(0,nneuts-midNeuts+1):
                     setupSequence = ''
 
                     # construct some permutation of the sequence
-                    for i in xrange(0,startNeuts):
-                        setupSequence += '0'
+                    
+                    setupSequence = '0'*startNeuts
 
                     setupSequence += posBlock
                     setupSequence += midBlock
                     setupSequence += negBlock
 
-                    for i in xrange(0,nneuts-startNeuts-midNeuts):
-                        setupSequence += '0'
 
-                    nseq = Sequence(setupSequence)
+                    setupSequence = setupSequence + '0'*(nneuts-startNeuts-midNeuts)
+
+                    nseq = Sequence(setupSequence)                    
 
                     # update self.dmax if relevant
                     self.dmax = max([nseq.delta(), self.dmax])
@@ -848,7 +937,7 @@ class Sequence:
     #
 
     #...................................................................................#
-    def setPhosPhoSites(self, listofPsites):
+    def setPhosPhoSites(self, listOfPsites):
         """
         Set one or more sites on your sequence which can be phosphorylated. Note that
         this indexes from 1 (like all of bioinformatics) and not from 0 (like all of 
@@ -871,7 +960,7 @@ class Sequence:
             listOfPsites.appned(tmp)
 
         # evaluate proposed phosphosites
-        for site in listofPsites:
+        for site in listOfPsites:
             
             # check we can convert to an integer!
             site = int(site)
@@ -965,7 +1054,7 @@ class Sequence:
             newseqObj = Sequence(newseq)
 
             # now add that new kappa to the list, update, and repeat!
-            phosphokappa.append((newseqObj.kappa(), newseqObj.Fplus(), newseqObj.Fminus(), newseqObj.FCR(), newseqObj.NCPR(), newseqObj.meanHydropathy()))
+            phosphokappa.append((newseqObj.kappa(), newseqObj.Fplus(), newseqObj.Fminus(), newseqObj.FCR(), newseqObj.NCPR(), newseqObj.meanHydropathy(), phosphostatus))
 
             print_progress(count, num_calcs)
             count=count+1
@@ -1067,22 +1156,81 @@ class Sequence:
 
     #...................................................................................#
     def toString(self):
+        """
+        
+
+        """
         s = "%i\t%3.5f\t%3.5f\t%3.5f\t%3.5f\t%3.5f\t%3.5f\t%3.5f\t%3.5f\t%3.5f" % (self.len,self.Fminus(),self.Fplus(),self.FCR(),self.NCPR(),self.sigma(),self.delta(),self.deltaMax(),self.kappa(),self.meanHydropathy())
         return s
 
 
+
+    def set_HTMLColorResiduePalette(self, colorDict):
+        """
+        Function which lets you userdefine the color pallete being used with a dictionary of [AA]="color" mappings where
+        color must be one of the 17 key HTML colours;
+
+        ['aqua', 'black', 'blue', 'fuchsia', 'gray', 'green', 'lime', 'maroon', 'navy', 'olive', 'orange', 'purple', 
+        'red', 'silver', 'teal', 'white', 'yellow']
+
+        """
+
+        valid={}
+
+        # for each one letter amino acid code
+        for i in aminoacids.ONE_TO_THREE:
+
+            # check all the amino acids were there
+            if i not in colorDict:
+                raise SequenceException("When trying to set amino acid color palette the amino acid " + str(i) + " was missing from the input dictionary") 
+
+            # check if the color is real
+            if colorDict[i] not in ['aqua', 'black', 'blue', 'fuchsia', 'gray', 'green', 'lime', 'maroon', 'navy', 'olive', 'orange', 'purple', 'red', 'silver', 'teal', 'white', 'yellow']:
+                raise SequenceException("When trying to set amino acid color palette the color " + str(colorDict[i]) + " was used, which is not one of the 17 standard HTML colours") 
+            
+            # if we get here update the 'valid' dictionary
+            valid[i] = colorDict[i].lower()    
+
+        # if we got here we got through the full 20 amino acids succesfully
+        self.aminoAcidColorMap = {}
+        for i in valid:
+            self.aminoAcidColorMap[i] = valid[i]
+
+            
+
+    def get_HTMLColorString(self):
+        """
+        Function which creates a <p> </p> wrapped HTML string with the sequence colored according to the defined
+        aminoAcidColorMap. 
+
+        """
+        colorString = '<p style="font-family:Courier;">'
+        count = -1
+        for residue in self.seq:
+            count = count + 1
+            if(np.mod(count,10) == 0):
+                colorString = colorString + " " 
+            if(np.mod(count,50) == 0):
+                colorString = colorString + "<br>" 
+
+            color = self.aminoAcidColorMap[residue]
+
+            colorString = '%s<span style="color:%s">%s</span>' % (colorString,color,residue)
+        colorString = colorString+ "</p>"
+        return colorString
+
     #...................................................................................#
     def toFileString(self):        
-        s = "Sequence    :\t%s\n\n" % (self.seq)
+        s = "Sequence   :\t%s\n\n" % (self.seq)
         s += "N          :\t%i\n" % (self.len)        
         s += "f-         :\t%3.5f\n" % (self.Fminus())
         s += "f+         :\t%3.5f\n" % (self.Fplus())
         s += "FCR        :\t%3.5f\n" % (self.FCR())
         s += "NCPR       :\t%3.5f\n" % (self.NCPR())
+        s += "Kappa      :\t%3.5f\n" % (self.kappa())
         s += "Sigma      :\t%3.5f\n" % (self.sigma())
         s += "Delta      :\t%3.5f\n" % (self.delta())
         s += "Max Delta  :\t%3.5f\n" % (self.deltaMax())        
-        s += "Kappa      :\t%3.5f\n" % (self.kappa())
         s += "Hydropathy :\t%3.5f\n\n" % (self.meanHydropathy())
         s += "Phase Plot Region: %i\n" % (self.phasePlotRegion())
         s += "Phase Plot Annotation: %s\n" % (self.phasePlotAnnotation())
