@@ -4,7 +4,7 @@
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.1                                                         !
+   !    Version 0.1.2                                                         !
    !--------------------------------------------------------------------------!
    
    File Description:
@@ -47,36 +47,45 @@
    linear NCPR etc) you must use a SequenceParameter object.
 
 """
+
 from backend import plotting
 
 
 #...................................................................................#
-def show_single_phasePlot(fp, fn, label="", title="Diagram of states", legendOn=True):
+def show_single_phasePlot(fp, fn, label="", title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
     """
     Plot a single sequence on the Pappu-Das phase plot (diagram of states).
 
-    INPUT
-    fp        | Fraction of positive residues
-    fn        | Fraction of negative residues
+    INPUT:
+    --------------------------------------------------------------------------------
+    fp         | Fraction of positive residues
+    fn         | Fraction of negative residues
     
-    label     | On-plot label of sequence (DEFAULT = no label)
-    title     | Plot title (DEFAULT = "Diagram of states")
-    legendOn  | Include the phase diagram region legend (DEFAULT = True)
-    
-    OUTPUT: 
+    label      | On-plot label of sequence (DEFAULT = no label)
+    title      | Plot title (DEFAULT = "Diagram of states")
+    legendOn   | Include the phase diagram region legend (DEFAULT = True)
+    xLim       | Set upper limit for the x axis (DEFAULT = 1)
+    yLim       | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize   | Set font size for the point labels (DEFAULT = 10)
+    getFig     | Returns a matplotlib figure object instead of simply displaying the 
+               | plot on the screen (DEFAULT = False)
+
+    OUTPUT:
+    --------------------------------------------------------------------------------
 
     Nothing but a plot should be generated on screen
     """
 
-    plotting.show_single_phasePlot(fp, fn, label, title, legendOn)
-
+    return plotting.show_single_phasePlot(fp, fn, label, title, legendOn, xLim, yLim, fontSize, getFig)
+    
 
 #...................................................................................#
-def save_single_phasePlot(fp, fn, filename, label="", title="Diagram of states", legendOn=True):
+def save_single_phasePlot(fp, fn, filename, label="", title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10):
     """
     Plot a single sequence on the Pappu-Das phase plot (diagram of states).
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     fp        | Fraction of positive residues
     fn        | Fraction of negative residues
     filename  | Path/name of file to save plot (.png is appended)
@@ -84,55 +93,73 @@ def save_single_phasePlot(fp, fn, filename, label="", title="Diagram of states",
     label     | On-plot label of sequence (DEFAULT = no label)
     title     | Plot title (DEFAULT = "Diagram of states")
     legendOn  | Include the phase diagram region legend (DEFAULT = True)
+    xLim      | Set upper limit for the x axis (DEFAULT = 1)
+    yLim      | Set upper limit for the x axis (DEFAULT = 1)
+    fontSize  | Set font size for the point labels (DEFAULT = 10)
 
     
     OUTPUT: 
-
+    --------------------------------------------------------------------------------
     Nothing but a plot should be generated on screen
+
     """
 
-    plotting.save_single_phasePlot(fp, fn, filename, label, title, legendOn)
+    plotting.save_single_phasePlot(fp, fn, filename, label, title, legendOn, xLim, yLim, fontSize)
 
 
 #...................................................................................#
-def show_multiple_phasePlot(fp_list, fn_list, label=[], title="Diagram of states", legendOn=True):
+def show_multiple_phasePlot(fp_list, fn_list, label=[""], title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
     """
     Plot multiple sequences on the same Pappu-Das phase plot (diagram of states).
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     fp_list    | Fraction of positive residues
     fn_list    | Fraction of negative residues
     
     label_list | On-plot label of sequence (DEFAULT = no label)
     title      | Plot title (DEFAULT = "Diagram of states")
     legendOn   | Include the phase diagram region legend (DEFAULT = True)
+    xLim       | Set upper limit for the x axis (DEFAULT = 1)
+    yLim       | Set upper limit for the x axis (DEFAULT = 1)
+    fontSize   | Set font size for the point labels (DEFAULT = 10)
+    getFig     | Returns a matplotlib figure object instead of simply displaying the 
+               | plot on the screen (DEFAULT = False)
     
-    
-    OUTPUT: 
 
+    OUTPUT: 
+    --------------------------------------------------------------------------------
     Nothing, but a plot with multiple points should appear on the screen 
+
     """
 
-    plotting.show_multiple_phasePlot(fp_list, fn_list, label, title, legendOn)
+    return plotting.show_multiple_phasePlot(fp_list, fn_list, label, title, legendOn, xLim, yLim, fontSize, getFig)
 
 
 #...................................................................................#
-def show_multiple_phasePlot2(SeqParam_list, label_list=[], title="Diagram of states", legendOn=True):
+def show_multiple_phasePlot2(SeqParam_list, label_list=[], title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
     """
     Plot a single sequence on the Pappu-Das phase plot (diagram of states). This function takes
     SequenceParameter objects rather than raw values
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     SeqParam_list | list of sequence parameter objects
     
     label         | On-plot label of sequence (DEFAULT = no label)
     title         | Plot title (DEFAULT = "Diagram of states")
     legendOn      | Include the phase diagram region legend (DEFAULT = True)
+    xLim          | Set upper limit for the x axis (DEFAULT = 1)
+    yLim          | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize      | Set font size for the point labels (DEFAULT = 10)
+    getFig        | Returns a matplotlib figure object instead of simply displaying the 
+                  | plot on the screen (DEFAULT = False)
+       
 
-        
     OUTPUT: 
-
+    --------------------------------------------------------------------------------
     Nothing, but a plot with multiple points should appear on the screen 
+    
     """
 
     # construct the fraction positive and negative vectors
@@ -142,15 +169,16 @@ def show_multiple_phasePlot2(SeqParam_list, label_list=[], title="Diagram of sta
         fp_list.append(seq.get_fraction_positive())
         fn_list.append(seq.get_fraction_negative())
 
-    plotting.show_multiple_phasePlot(fp_list, fn_list, label_list, title, legendOn)
+    return plotting.show_multiple_phasePlot(fp_list, fn_list, label_list, title, legendOn, xLim, yLim, fontSize, getFig)
     
 
 #...................................................................................#
-def save_multiple_phasePlot(fp_list, fn_list, filename, label_list=[], title="Diagram of states", legendOn=True):
+def save_multiple_phasePlot(fp_list, fn_list, filename, label_list=[], title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10):
     """
     Plot multiple sequences on the same Pappu-Das phase plot (diagram of states) and save that file
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     fp_list    | Fraction of positive residues
     fn_list    | Fraction of negative residues
     filename   | name of file to save (.png is appended)
@@ -158,34 +186,43 @@ def save_multiple_phasePlot(fp_list, fn_list, filename, label_list=[], title="Di
     label_list | On-plot label of sequence (DEFAULT = no label)
     title      | Plot title (DEFAULT = "Diagram of states")
     legendOn   | Include the phase diagram region legend (DEFAULT = True)
-    
+    xLim       | Set upper limit for the x axis (DEFAULT = 1)
+    yLim       | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize   | Set font size for the point labels (DEFAULT = 10)
+
     
     OUTPUT: 
-
+    --------------------------------------------------------------------------------
     No output, but if succesful a file with filename is generated with the associated plot
+
     """
 
-    plotting.save_multiple_phasePlot(fp_list, fn_list, filename, label_list, title, legendOn)
+    plotting.save_multiple_phasePlot(fp_list, fn_list, filename, label_list, title, legendOn, xLim, yLim, fontSize)
 
 
 #...................................................................................#
-def save_multiple_phasePlot2(SeqParam_list, filename, label_list=[], title="Diagram of states", legendOn=True):
+def save_multiple_phasePlot2(SeqParam_list, filename, label_list=[], title="Diagram of states", legendOn=True, xLim=1, yLim=1, fontSize=10):
     """
     Plot multiple sequences on the same Pappu-Das phase plot (diagram of states) and save that file. 
     This function takes SequenceParameter objects rather than raw values.
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     SeqParam_list | list of sequence parameter objects
     filename      | name of file to save (.png is appended)
     
     label_list    | On-plot label of sequence (DEFAULT = no label)
     title         | Plot title (DEFAULT = "Diagram of states")
     legendOn      | Include the phase diagram region legend (DEFAULT = True)
+    xLim          | Set upper limit for the x axis (DEFAULT = 1)
+    yLim          | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize      | Set font size for the point labels (DEFAULT = 10)    
     
-    
-    OUTPUT: 
 
+    OUTPUT: 
+    --------------------------------------------------------------------------------
     No output, but if succesful a file with filename is generated with the associated plot
+
     """
 
     # construct the fraction positive and negative vectors
@@ -195,7 +232,7 @@ def save_multiple_phasePlot2(SeqParam_list, filename, label_list=[], title="Diag
         fp_list.append(seq.get_fraction_positive())
         fn_list.append(seq.get_fraction_negative())
 
-    plotting.save_multiple_phasePlot(fp_list, fn_list, filename, label_list, title, legendOn)
+    plotting.save_multiple_phasePlot(fp_list, fn_list, filename, label_list, title, legendOn, xLim, yLim, fontSize)
 
 
 ####################################################
@@ -205,35 +242,43 @@ def save_multiple_phasePlot2(SeqParam_list, filename, label_list=[], title="Diag
 ####################################################
 
 #...................................................................................#
-def show_single_uverskyPlot(hydropathy, mean_net_charge, label="", title="Uversky plot", legendOn=True):
+def show_single_uverskyPlot(hydropathy, mean_net_charge, label="", title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
     """
     Plots a single sequence on the Uversky plot (hydropathy vs. mean net charge)
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     hydropathy      | Mean hydropathy for sequence
     mean_net_charge | Absolute magnitude of the protein's net charge divided by sequence length
     
-
-    
     label           | On-plot label of sequence (DEFAULT = no label)
     title           | Plot title (DEFAULT = "Uversky plot")
     legendOn        | Include the phase diagram region legend (DEFAULT = True)
-    
-    OUTPUT: 
+    xLim            | Set upper limit for the x axis (DEFAULT = 1)
+    yLim            | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize        | Set font size for the point labels (DEFAULT = 10)    
+    getFig          | Returns a matplotlib figure object instead of simply displaying the 
+                    | plot on the screen (DEFAULT = False)
 
+
+
+    OUTPUT: 
+    --------------------------------------------------------------------------------
     Nothing, but an annotated Uversky plot should be generated on screen
+
     """
 
-    plotting.show_single_uverskyPlot(hydropathy, mean_net_charge, label, title, legendOn)
+    return plotting.show_single_uverskyPlot(hydropathy, mean_net_charge, label, title, legendOn, xLim, yLim, fontSize, getFig)
 
 
 #...................................................................................#
-def save_single_uverskyPlot(hydropathy, mean_net_charge, filename, label="", title="Uversky plot", legendOn=True):
+def save_single_uverskyPlot(hydropathy, mean_net_charge, filename, label="", title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10):
     """
     Plots a single sequence on the Uversky plot (hydropathy vs. mean net charge) and save it to 'filename' (.png is
     appended).
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     hydropathy      | Mean hydropathy for sequence
     mean_net_charge | Absolute magnitude of the protein's net charge divided by sequence length
     filename        | Path/name of file to save plot (.png is appended)
@@ -241,55 +286,72 @@ def save_single_uverskyPlot(hydropathy, mean_net_charge, filename, label="", tit
     label           | On-plot label of sequence (DEFAULT = no label)
     title           | Plot title (DEFAULT = "Uversky plot")
     legendOn        | Include the phase diagram region legend (DEFAULT = True)
-
+    xLim            | Set upper limit for the x axis (DEFAULT = 1)
+    yLim            | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize        | Set font size for the point labels (DEFAULT = 10)
     
-    OUTPUT: 
 
+    OUTPUT: 
+    --------------------------------------------------------------------------------
     Nothing but single uversky plot should be saved to disk
+
     """
 
-    plotting.save_single_uverskyPlot(hydropathy, mean_net_charge, filename, label, title, legendOn)
+    plotting.save_single_uverskyPlot(hydropathy, mean_net_charge, filename, label, title, legendOn, xLim, yLim, fontSize)
 
 
 #...................................................................................#
-def show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list=[], title="Uversky plot", legendOn=True):
+def show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list=[], title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
     """
     Plots multiple sequences on the Uversky plot (hydropathy vs. mean net charge) and shows the plot on the screen.
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     hydropathy_list      | List of proteins' mean hydropathy
     mean_net_charge_list | List of the absolute magnitude of the protein's net charge divided by sequence length
     
-    label_list            | List of labels for each sequence (empty = no list)
+    label_list           | List of labels for each sequence (empty = no list)
     title                | Plot title (DEFAULT = "Uversky plot")
     legendOn             | Include the phase diagram region legend (DEFAULT = True)
-    
+    xLim                 | Set upper limit for the x axis (DEFAULT = 1)
+    yLim                 | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize             | Set font size for the point labels (DEFAULT = 10)    
+    getFig               | Returns a matplotlib figure object instead of simply displaying the 
+                         | plot on the screen (DEFAULT = False)
+
     
     OUTPUT: 
-
+    --------------------------------------------------------------------------------
     Nothing, but a Uversky plot with multiple points should appear on the screen 
 
     """
-    plotting.show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list, title, legendOn)
+    return plotting.show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list, title, legendOn, xLim, yLim, fontSize, getFig)
 
 
 #...................................................................................#
-def show_multiple_uverskyPlot2(SeqParam_list, label_list=[], title="Uversky plot", legendOn=True):
+def show_multiple_uverskyPlot2(SeqParam_list, label_list=[], title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10, getFig=False):
     """
     Plots multiple sequences on the Uversky plot (hydropathy vs. mean net charge) and shows the plot on the screen.
     This function takes a list of SequenceParameter objects instead of the actual values
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     SeqParam_list        | List of sequence parameter objects
     
     label_list           | List of labels for each sequence (empty = no list)
     title                | Plot title (DEFAULT = "Uversky plot")
     legendOn             | Include the phase diagram region legend (DEFAULT = True)
-    
+    xLim                 | Set upper limit for the x axis (DEFAULT = 1)
+    yLim                 | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize             | Set font size for the point labels (DEFAULT = 10)    
+    getFig               | Returns a matplotlib figure object instead of simply displaying the 
+                         | plot on the screen (DEFAULT = False)
+
     
     OUTPUT: 
-
+    --------------------------------------------------------------------------------
     Nothing, but a Uversky plot with multiple points should appear on the screen 
+
     """
 
     # construct the fraction positive and negative vectors
@@ -299,16 +361,17 @@ def show_multiple_uverskyPlot2(SeqParam_list, label_list=[], title="Uversky plot
         hydropathy_list.append(seq.get_uversky_hydrophobicity())
         mean_net_charge_list.append(seq.get_mean_net_charge())
 
-    plotting.show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list, title, legendOn)
+    return plotting.show_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, label_list, title, legendOn, xLim, yLim, fontSize, getFig)
 
 
 #...................................................................................#
-def save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list=[], title="Uversky plot", legendOn=True):
+def save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list=[], title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10):
     """
     Plots multiple sequences on the Uversky plot (hydropathy vs. mean net charge) and saves that plot to 'filename' (.png
     is appended).
 
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     hydropathy           | List of mean hydropathies for sequences
     mean_net_charge_list | List of the absolute magnitude of the protein's net charge divided by sequence length
     filename             | Path/name of file to save plot (.png is appended)
@@ -316,38 +379,45 @@ def save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, l
     label_list           | List of labels for each sequence (empty = no list)
     title                | Plot title (DEFAULT = "Uversky plot")
     legendOn             | Include the phase diagram region legend (DEFAULT = True)
+    xLim                 | Set upper limit for the x axis (DEFAULT = 1)
+    yLim                 | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize             | Set font size for the point labels (DEFAULT = 10)    
     
-    
+
     OUTPUT: 
-
-
+    --------------------------------------------------------------------------------
     Nothing, but a Uversky plot with multiple points should be saved to the 'filename', where filename
     defines the name of a file/path for saving
+
     """
 
-    plotting.save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list, title, legendOn)
+    plotting.save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list, title, legendOn, xLim, yLim, fontSize)
 
 
 #...................................................................................#
-def save_multiple_uverskyPlot2(SeqParam_list, filename, label_list=[], title="Uversky plot", legendOn=True):
+def save_multiple_uverskyPlot2(SeqParam_list, filename, label_list=[], title="Uversky plot", legendOn=True, xLim=1, yLim=1, fontSize=10):
     """
     Plots multiple sequences on the Uversky plot (hydropathy vs. mean net charge) and saves that plot to 'filename' (.png
     is appended). This function takes SequenceParameter objects instead of list of hydrophobicity and mean_net_charge
     values
     
-
-
-    INPUT
+    INPUT:
+    --------------------------------------------------------------------------------
     SeqParam_list   | List of sequence parameter objects
     filename        | Path/name of file to save plot (.png is appended)
    
     label           | On-plot label of sequence (DEFAULT = no label)
     title           | Plot title (DEFAULT = "Uversky plot")
     legendOn        | Include the phase diagram region legend (DEFAULT = True)
+    xLim            | Set upper limit for the x axis (DEFAULT = 1)
+    yLim            | Set upper limit for the y axis (DEFAULT = 1)
+    fontSize        | Set font size for the point labels (DEFAULT = 10)     
     
-    
-    OUTPUT: 
 
+    OUTPUT: 
+    --------------------------------------------------------------------------------
+    Nothing, but a Uversky plot with multiple points should be saved to the 'filename', where filename
+    defines the name of a file/path for saving
     
     """
 
@@ -359,6 +429,5 @@ def save_multiple_uverskyPlot2(SeqParam_list, filename, label_list=[], title="Uv
         mean_net_charge_list.append(seq.get_mean_net_charge())
 
 
-    plotting.save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list, title, legendOn)
+    plotting.save_multiple_uverskyPlot(hydropathy_list, mean_net_charge_list, filename, label_list, title, legendOn, xLim, yLim, fontSize)
 
-    
