@@ -4,7 +4,7 @@
    !--------------------------------------------------------------------------!
    !    This file is part of localCIDER.                                      !
    !                                                                          !
-   !    Version 0.1.1                                                         !
+   !    Version 0.1.2                                                         !
    !                                                                          !
    !    Copyright (C) 2014, The localCIDER development team (current and      !
    !                        former contributors): Alex Holehouse, James       !
@@ -45,6 +45,7 @@
 
 
 """
+
 import os.path, time
 import unittest
 import random
@@ -80,8 +81,8 @@ class TestSequenceParametersFunctions(unittest.TestCase):
         MH = self.testObj.get_mean_hydropathy()
         self.assertEqual(MH,3.242142857142857)
 
-    def test_get_uversky_hydrophobicity(self):
-        MUH = self.testObj.get_uversky_hydrophobicity()
+    def test_get_uversky_hydropathy(self):
+        MUH = self.testObj.get_uversky_hydropathy()
         self.assertEqual(MUH, 0.4552380952380952)
         
     def test_get_fraction_disorder_promoting(self):
@@ -187,53 +188,61 @@ class TestSequenceParametersFunctions(unittest.TestCase):
         self.testObj.set_phosphosites([33,39,42])
 
         FPKD = [(0.17167490749129125,
-          0.10714285714285714,
-          0.17142857142857143,
-          0.2785714285714286,
-          -0.06428571428571428,
-          3.242142857142857),
-         (0.16068627291329185,
-          0.10714285714285714,
-          0.17857142857142858,
-          0.2857142857142857,
-          -0.07142857142857142,
-          3.222857142857143),
-         (0.16863038053131135,
-          0.10714285714285714,
-          0.17857142857142858,
-          0.2857142857142857,
-          -0.07142857142857142,
-          3.226428571428571),
-         (0.1609064850879989,
-          0.10714285714285714,
-          0.18571428571428572,
-          0.29285714285714287,
-          -0.07857142857142857,
-          3.207142857142857),
-         (0.161014373883184,
-          0.10714285714285714,
-          0.17857142857142858,
-          0.2857142857142857,
-          -0.07142857142857142,
-          3.2221428571428574),
-         (0.15064319064948062,
-          0.10714285714285714,
-          0.18571428571428572,
-          0.29285714285714287,
-          -0.07857142857142857,
-          3.2028571428571424),
-         (0.15825014591368247,
-          0.10714285714285714,
-          0.18571428571428572,
-          0.29285714285714287,
-          -0.07857142857142857,
-          3.2064285714285714),
-         (0.15101360943849682,
-          0.10714285714285714,
-          0.19285714285714287,
-          0.3,
-          -0.08571428571428572,
-          3.1871428571428573)]
+                 0.10714285714285714,
+                 0.17142857142857143,
+                 0.2785714285714286,
+                 -0.06428571428571428,
+                 3.242142857142857,
+                 ('0', '0', '0')),
+                (0.16068627291329185,
+                 0.10714285714285714,
+                 0.17857142857142858,
+                 0.2857142857142857,
+                 -0.07142857142857142,
+                 3.222857142857143,
+                 ('0', '0', '1')),
+                (0.16863038053131135,
+                 0.10714285714285714,
+                 0.17857142857142858,
+                 0.2857142857142857,
+                 -0.07142857142857142,
+                 3.226428571428571,
+                 ('0', '1', '0')),
+                (0.1609064850879989,
+                 0.10714285714285714,
+                 0.18571428571428572,
+                 0.29285714285714287,
+                 -0.07857142857142857,
+                 3.207142857142857,
+                 ('0', '1', '1')),
+                (0.161014373883184,
+                 0.10714285714285714,
+                 0.17857142857142858,
+                 0.2857142857142857,
+                 -0.07142857142857142,
+                 3.2221428571428574,
+                 ('1', '0', '0')),
+                (0.15064319064948062,
+                 0.10714285714285714,
+                 0.18571428571428572,
+                 0.29285714285714287,
+                 -0.07857142857142857,
+                 3.2028571428571424,
+                 ('1', '0', '1')),
+                (0.15825014591368247,
+                 0.10714285714285714,
+                 0.18571428571428572,
+                 0.29285714285714287,
+                 -0.07857142857142857,
+                 3.2064285714285714,
+                 ('1', '1', '0')),
+                (0.15101360943849682,
+                 0.10714285714285714,
+                 0.19285714285714287,
+                 0.3,
+                 -0.08571428571428572,
+                 3.1871428571428573,
+                 ('1', '1', '1'))]
 
         FPKD_calc = self.testObj.get_full_phosphostatus_kappa_distribution()
 
@@ -309,7 +318,7 @@ class TestSequenceParametersFunctions(unittest.TestCase):
             iSEQ.get_mean_net_charge()
             iSEQ.get_phasePlotRegion()
             iSEQ.get_mean_hydropathy()
-            iSEQ.get_uversky_hydrophobicity()
+            iSEQ.get_uversky_hydropathy()
             psites=iSEQ.get_all_phosphorylatable_sites()
             if psites > 0:
 
@@ -322,12 +331,21 @@ class TestSequenceParametersFunctions(unittest.TestCase):
                 iSEQ.get_phosphosequence()
                 iSEQ.get_full_phosphostatus_kappa_distribution()
                 iSEQ.clear_phosphosites()
-
+        
+            # single 
             iSEQ.save_phaseDiagramPlot("tmpfiles/phase_test_S"+str(pos))
             iSEQ.save_uverskyPlot("tmpfiles/uversky_test_S"+str(pos))
-            iSEQ.save_linearNCPR(6,"tmpfiles/NCPR_test_S"+str(pos))
-            iSEQ.save_linearHydropathy(6,"tmpfiles/Hydropathy_test_S"+str(pos))
-            iSEQ.save_linearSigma(6,"tmpfiles/sigma_test_S"+str(pos))
+
+            # try with a blobval
+            iSEQ.save_linearNCPR("tmpfiles/NCPR_test_S"+str(pos),5)
+            iSEQ.save_linearHydropathy("tmpfiles/Hydropathy_test_S"+str(pos),5)
+            iSEQ.save_linearSigma("tmpfiles/sigma_test_S"+str(pos),5)
+            
+            # try with default
+            iSEQ.save_linearNCPR("tmpfiles/NCPR_test_S"+str(pos))
+            iSEQ.save_linearHydropathy("tmpfiles/Hydropathy_test_S"+str(pos))
+            iSEQ.save_linearSigma("tmpfiles/sigma_test_S"+str(pos))
+
 
             pos=pos+1
                 
